<?php
/**
 * Cooking Food Blogger Theme Customizer
 *
 * @link: https://developer.wordpress.org/themes/customize-api/customizer-objects/
 *
 * @package Cooking Food Blogger
 */

if ( ! defined( 'COOKING_FOOD_BLOGGER_URL' ) ) {
    define( 'COOKING_FOOD_BLOGGER_URL', esc_url( 'https://www.themagnifico.net/themes/cooking-wordpress-theme/', 'cooking-food-blogger') );
}

if ( ! defined( 'COOKING_FOOD_BLOGGER_BUY_TEXT' ) ) {
    define( 'COOKING_FOOD_BLOGGER_BUY_TEXT', __( 'Buy Food Blogger Pro','cooking-food-blogger' ));
}

use WPTRT\Customize\Section\Cooking_Food_Blogger_Button;

add_action( 'customize_register', function( $manager ) {

    $manager->register_section_type( Cooking_Food_Blogger_Button::class );

    $manager->add_section(
        new Cooking_Food_Blogger_Button( $manager, 'cooking_food_blogger_pro', [
            'title'       => __( 'Food Blogger Pro', 'cooking-food-blogger' ),
            'priority'    => 0,
            'button_text' => __( 'GET PREMIUM', 'cooking-food-blogger' ),
            'button_url'  => esc_url( 'https://www.themagnifico.net/themes/cooking-wordpress-theme/', 'cooking-food-blogger')
        ] )
    );

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

    $version = wp_get_theme()->get( 'Version' );

    wp_enqueue_script(
        'cooking-food-blogger-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
        [ 'customize-controls' ],
        $version,
        true
    );

    wp_enqueue_style(
        'cooking-food-blogger-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
        [ 'customize-controls' ],
        $version
    );

} );

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function cooking_food_blogger_customize_register($wp_customize){

     // Pro Version
    class Cooking_Food_Blogger_Customize_Pro_Version extends WP_Customize_Control {
        public $type = 'pro_options';

        public function render_content() {
            echo '<span>For More <strong>'. esc_html( $this->label ) .'</strong>?</span>';
            echo '<a href="'. esc_url($this->description) .'" target="_blank">';
                echo '<span class="dashicons dashicons-info"></span>';
                echo '<strong> '. esc_html( COOKING_FOOD_BLOGGER_BUY_TEXT,'cooking-food-blogger' ) .'<strong></a>';
            echo '</a>';
        }
    }

    // Custom Controls
    function Cooking_Food_Blogger_sanitize_custom_control( $input ) {
        return $input;
    }

    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';

    //Logo
    $wp_customize->add_setting('cooking_food_blogger_logo_max_height',array(
        'default'   => '24',
        'sanitize_callback' => 'cooking_food_blogger_sanitize_number_absint'
    ));
    $wp_customize->add_control('cooking_food_blogger_logo_max_height',array(
        'label' => esc_html__('Logo Width','cooking-food-blogger'),
        'section'   => 'title_tagline',
        'type'      => 'number'
    ));

    $wp_customize->add_setting('cooking_food_blogger_logo_title_text', array(
        'default' => true,
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'cooking_food_blogger_logo_title_text',array(
        'label'          => __( 'Enable Disable Title', 'cooking-food-blogger' ),
        'section'        => 'title_tagline',
        'settings'       => 'cooking_food_blogger_logo_title_text',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('cooking_food_blogger_theme_description', array(
        'default' => false,
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'cooking_food_blogger_theme_description',array(
        'label'          => __( 'Enable Disable Tagline', 'cooking-food-blogger' ),
        'section'        => 'title_tagline',
        'settings'       => 'cooking_food_blogger_theme_description',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('cooking_food_blogger_logo_title_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cooking_food_blogger_logo_title_color', array(
        'label'    => __('Site Title Color', 'cooking-food-blogger'),
        'section'  => 'title_tagline'
    )));

    $wp_customize->add_setting('cooking_food_blogger_logo_tagline_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cooking_food_blogger_logo_tagline_color', array(
        'label'    => __('Site Tagline Color', 'cooking-food-blogger'),
        'section'  => 'title_tagline'
    )));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_logo', array(
        'sanitize_callback' => 'Cooking_Food_Blogger_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Cooking_Food_Blogger_Customize_Pro_Version ( $wp_customize,'pro_version_logo', array(
                'section'     => 'title_tagline',
                'type'        => 'pro_options',
                'label'       => esc_html__( 'Customizer Options', 'cooking-food-blogger' ),
                'description' => esc_url( COOKING_FOOD_BLOGGER_URL ),
                'priority'    => 100
    )));

    //General Setting
    $wp_customize->add_section('cooking_food_blogger_general_settings',array(
        'title' => esc_html__('General Setting','cooking-food-blogger'),
        'priority'   => 10,
    ));

    $wp_customize->add_setting('cooking_food_blogger_preloader_hide', array(
        'default' => false,
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'cooking_food_blogger_preloader_hide',array(
        'label'          => __( 'Show Theme Preloader', 'cooking-food-blogger' ),
        'section'        => 'cooking_food_blogger_general_settings',
        'settings'       => 'cooking_food_blogger_preloader_hide',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting( 'cooking_food_blogger_preloader_bg_color', array(
        'default' => '#ffffff',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'cooking_food_blogger_preloader_bg_color', array(
        'label' => esc_html__('Preloader Background Color','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_general_settings',
        'settings' => 'cooking_food_blogger_preloader_bg_color'
    )));

    $wp_customize->add_setting( 'cooking_food_blogger_preloader_dot_1_color', array(
        'default' => '#ff9500',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'cooking_food_blogger_preloader_dot_1_color', array(
        'label' => esc_html__('Preloader First Dot Color','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_general_settings',
        'settings' => 'cooking_food_blogger_preloader_dot_1_color'
    )));

    $wp_customize->add_setting( 'cooking_food_blogger_preloader_dot_2_color', array(
        'default' => '#011627',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'cooking_food_blogger_preloader_dot_2_color', array(
        'label' => esc_html__('Preloader Second Dot Color','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_general_settings',
        'settings' => 'cooking_food_blogger_preloader_dot_2_color'
    )));

    $wp_customize->add_setting('cooking_food_blogger_scroll_hide', array(
        'default' => false,
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'cooking_food_blogger_scroll_hide',array(
        'label'          => __( 'Show Theme Scroll To Top', 'cooking-food-blogger' ),
        'section'        => 'cooking_food_blogger_general_settings',
        'settings'       => 'cooking_food_blogger_scroll_hide',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('cooking_food_blogger_scroll_top_position',array(
        'default' => 'Right',
        'sanitize_callback' => 'cooking_food_blogger_sanitize_choices'
    ));
    $wp_customize->add_control('cooking_food_blogger_scroll_top_position',array(
        'label'       => esc_html__( 'Scroll To Top Positions','cooking-food-blogger' ),
        'type' => 'radio',
        'section' => 'cooking_food_blogger_general_settings',
        'choices' => array(
            'Right' => __('Right','cooking-food-blogger'),
            'Left' => __('Left','cooking-food-blogger'),
            'Center' => __('Center','cooking-food-blogger')
        ),
    ) );

    $wp_customize->add_setting( 'cooking_food_blogger_scroll_to_top_border_radius', array(
        'default'              => '',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'cooking_food_blogger_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'cooking_food_blogger_scroll_to_top_border_radius', array(
        'label'       => esc_html__( 'Scroll To Top Border Radius','cooking-food-blogger' ),
        'section'     => 'cooking_food_blogger_general_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 50,
        ),
    ) );

    // Product Columns
   $wp_customize->add_setting( 'cooking_food_blogger_products_per_row' , array(
       'default'           => '3',
       'transport'         => 'refresh',
       'sanitize_callback' => 'cooking_food_blogger_sanitize_select',
   ) );

   $wp_customize->add_control('cooking_food_blogger_products_per_row', array(
       'label' => __( 'Product per row', 'cooking-food-blogger' ),
       'section'  => 'cooking_food_blogger_general_settings',
       'type'     => 'select',
       'choices'  => array(
           '2' => '2',
           '3' => '3',
           '4' => '4',
       ),
   ) );

   //Woocommerce shop page Sidebar
    $wp_customize->add_setting('cooking_food_blogger_woocommerce_shop_page_sidebar', array(
        'default' => true,
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'cooking_food_blogger_woocommerce_shop_page_sidebar',array(
        'label'          => __( 'Hide Shop Page Sidebar', 'cooking-food-blogger' ),
        'section'        => 'cooking_food_blogger_general_settings',
        'settings'       => 'cooking_food_blogger_woocommerce_shop_page_sidebar',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('cooking_food_blogger_shop_page_sidebar_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'cooking_food_blogger_sanitize_choices'
    ));
    $wp_customize->add_control('cooking_food_blogger_shop_page_sidebar_layout',array(
        'type' => 'select',
        'label' => __('Woocommerce Shop Page Sidebar','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_general_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','cooking-food-blogger'),
            'Right Sidebar' => __('Right Sidebar','cooking-food-blogger'),
        ),
    ) );

    //Woocommerce Single Product page Sidebar
    $wp_customize->add_setting('cooking_food_blogger_woocommerce_single_product_page_sidebar', array(
        'default' => true,
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'cooking_food_blogger_woocommerce_single_product_page_sidebar',array(
        'label'          => __( 'Hide Single Product Page Sidebar', 'cooking-food-blogger' ),
        'section'        => 'cooking_food_blogger_general_settings',
        'settings'       => 'cooking_food_blogger_woocommerce_single_product_page_sidebar',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('cooking_food_blogger_single_product_sidebar_layout',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'cooking_food_blogger_sanitize_choices'
    ));
    $wp_customize->add_control('cooking_food_blogger_single_product_sidebar_layout',array(
        'type' => 'select',
        'label' => __('Woocommerce Single Product Page Sidebar','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_general_settings',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','cooking-food-blogger'),
            'Right Sidebar' => __('Right Sidebar','cooking-food-blogger'),
        ),
    ) );

    $wp_customize->add_setting('cooking_food_blogger_woocommerce_product_sale',array(
        'default' => 'Left',
        'sanitize_callback' => 'cooking_food_blogger_sanitize_choices'
    ));
    $wp_customize->add_control('cooking_food_blogger_woocommerce_product_sale',array(
        'label'       => esc_html__( 'Woocommerce Product Sale Positions','cooking-food-blogger' ),
        'type' => 'radio',
        'section' => 'cooking_food_blogger_general_settings',
        'choices' => array(
            'Right' => __('Right','cooking-food-blogger'),
            'Left' => __('Left','cooking-food-blogger'),
            'Center' => __('Center','cooking-food-blogger')
        ),
    ) );

     $wp_customize->add_setting( 'cooking_food_blogger_woo_product_sale_border_radius', array(
        'default'              => '',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'cooking_food_blogger_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'cooking_food_blogger_woo_product_sale_border_radius', array(
        'label'       => esc_html__( 'Woocommerce Product Sale Border Radius','cooking-food-blogger' ),
        'section'     => 'cooking_food_blogger_general_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 50,
        ),
    ) );

    //Products border radius
    $wp_customize->add_setting( 'cooking_food_blogger_woo_product_border_radius', array(
        'default'              => '0',
        'transport'            => 'refresh',
        'sanitize_callback'    => 'cooking_food_blogger_sanitize_number_range'
    ) );
    $wp_customize->add_control( 'cooking_food_blogger_woo_product_border_radius', array(
        'label'       => esc_html__( 'Product Border Radius','cooking-food-blogger' ),
        'section'     => 'cooking_food_blogger_general_settings',
        'type'        => 'range',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 1,
            'max'              => 150,
        ),
    ) );

    // Pro Version
    $wp_customize->add_setting( 'pro_version_general_setting', array(
        'sanitize_callback' => 'Cooking_Food_Blogger_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Cooking_Food_Blogger_Customize_Pro_Version ( $wp_customize,'pro_version_general_setting', array(
                'section'     => 'cooking_food_blogger_general_settings',
                'type'        => 'pro_options',
                'label'       => esc_html__( 'Customizer Options', 'cooking-food-blogger' ),
                'description' => esc_url( COOKING_FOOD_BLOGGER_URL ),
                'priority'    => 100
    )));

    //Header
    $wp_customize->add_section('cooking_food_blogger_header',array(
        'title' => esc_html__('Header Option','cooking-food-blogger')
    ));

    $wp_customize->add_setting('cooking_food_blogger_header_setting', array(
        'default' => 0,
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'cooking_food_blogger_header_setting',array(
        'label'          => __( 'Enable Disable Header', 'cooking-food-blogger' ),
        'section'        => 'cooking_food_blogger_header',
        'settings'       => 'cooking_food_blogger_header_setting',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('cooking_food_blogger_header_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_header_text',array(
        'label' => esc_html__('Header Text','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_header',
        'setting' => 'cooking_food_blogger_header_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_opening_date',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_opening_date',array(
        'label' => esc_html__('Classes Date','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_header',
        'setting' => 'cooking_food_blogger_opening_date',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_email',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_email'
    ));
    $wp_customize->add_control('cooking_food_blogger_email',array(
        'label' => esc_html__('Email Address','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_header',
        'setting' => 'cooking_food_blogger_email',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_phone_number',array(
        'default' => '',
        'sanitize_callback' => 'cooking_food_blogger_sanitize_phone_number'
    ));
    $wp_customize->add_control('cooking_food_blogger_phone_number',array(
        'label' => esc_html__('Phone Number','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_header',
        'setting' => 'cooking_food_blogger_phone_number',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_button_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_button_text',array(
        'label' => esc_html__('Button Text','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_header',
        'setting' => 'cooking_food_blogger_button_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_button_link',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('cooking_food_blogger_button_link',array(
        'label' => esc_html__('Button Url','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_header',
        'setting' => 'cooking_food_blogger_button_link',
        'type'  => 'text'
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_header_setting', array(
        'sanitize_callback' => 'Cooking_Food_Blogger_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Cooking_Food_Blogger_Customize_Pro_Version ( $wp_customize,'pro_version_header_setting', array(
                'section'     => 'cooking_food_blogger_header',
                'type'        => 'pro_options',
                'label'       => esc_html__( 'Customizer Options', 'cooking-food-blogger' ),
                'description' => esc_url( COOKING_FOOD_BLOGGER_URL ),
                'priority'    => 100
    )));

    // Slider
    $wp_customize->add_section('cooking_food_blogger_top_slider',array(
        'title' => esc_html__('Slider Option','cooking-food-blogger')
    ));

    $wp_customize->add_setting('cooking_food_blogger_slider_setting', array(
        'default' => 0,
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'cooking_food_blogger_slider_setting',array(
        'label'          => __( 'Enable Disable Slider', 'cooking-food-blogger' ),
        'section'        => 'cooking_food_blogger_top_slider',
        'settings'       => 'cooking_food_blogger_slider_setting',
        'type'           => 'checkbox',
    )));

    for ( $count = 1; $count <= 3; $count++ ) {
        $wp_customize->add_setting( 'cooking_food_blogger_top_slider_page' . $count, array(
            'default'           => '',
            'sanitize_callback' => 'cooking_food_blogger_sanitize_dropdown_pages'
        ) );
        $wp_customize->add_control( 'cooking_food_blogger_top_slider_page' . $count, array(
            'label'    => __( 'Select Slide Page', 'cooking-food-blogger' ),
            'section'  => 'cooking_food_blogger_top_slider',
            'type'     => 'dropdown-pages'
        ) );
    }

    $wp_customize->add_setting('cooking_food_blogger_slider_video',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('cooking_food_blogger_slider_video',array(
        'label' => esc_html__('Add YouTube Embeded Link','cooking-food-blogger'),
        'description' => esc_html__('ex: https://www.youtube.com/embed/OrW7tnyZD4Q','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_top_slider',
        'setting' => 'cooking_food_blogger_slider_video',
        'type'  => 'url'
    ));

    //Slider Image Opacity
    $wp_customize->add_setting('cooking_food_blogger_slider_opacity_color',array(
      'default' => '',
      'sanitize_callback' => 'cooking_food_blogger_sanitize_choices'
    ));

    $wp_customize->add_control( 'cooking_food_blogger_slider_opacity_color', array(
    'label'       => esc_html__( 'Slider Image Opacity','cooking-food-blogger' ),
    'section'     => 'cooking_food_blogger_top_slider',
    'type'        => 'select',
    'choices' => array(
      '0' =>  esc_attr('0','cooking-food-blogger'),
      '0.1' =>  esc_attr('0.1','cooking-food-blogger'),
      '0.2' =>  esc_attr('0.2','cooking-food-blogger'),
      '0.3' =>  esc_attr('0.3','cooking-food-blogger'),
      '0.4' =>  esc_attr('0.4','cooking-food-blogger'),
      '0.5' =>  esc_attr('0.5','cooking-food-blogger'),
      '0.6' =>  esc_attr('0.6','cooking-food-blogger'),
      '0.7' =>  esc_attr('0.7','cooking-food-blogger'),
      '0.8' =>  esc_attr('0.8','cooking-food-blogger'),
      '0.9' =>  esc_attr('0.9','cooking-food-blogger')
    ),
    ));

    //Slider height
    $wp_customize->add_setting('cooking_food_blogger_slider_img_height',array(
        'default'=> '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_slider_img_height',array(
        'label' => __('Slider Height','cooking-food-blogger'),
        'description'   => __('Add the slider height in px(eg. 500px).','cooking-food-blogger'),
        'input_attrs' => array(
            'placeholder' => __( '500px', 'cooking-food-blogger' ),
        ),
        'section'=> 'cooking_food_blogger_top_slider',
        'type'=> 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_social_icon_setting', array(
        'default' => false,
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'cooking_food_blogger_social_icon_setting',array(
        'label'          => __( 'Enable Disable Social Icon', 'cooking-food-blogger' ),
        'section'        => 'cooking_food_blogger_top_slider',
        'settings'       => 'cooking_food_blogger_social_icon_setting',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('cooking_food_blogger_facebook_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('cooking_food_blogger_facebook_url',array(
        'label' => esc_html__('Facebook Link','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_top_slider',
        'setting' => 'cooking_food_blogger_facebook_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('cooking_food_blogger_twitter_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('cooking_food_blogger_twitter_url',array(
        'label' => esc_html__('Twitter Link','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_top_slider',
        'setting' => 'cooking_food_blogger_twitter_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('cooking_food_blogger_intagram_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('cooking_food_blogger_intagram_url',array(
        'label' => esc_html__('Intagram Link','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_top_slider',
        'setting' => 'cooking_food_blogger_intagram_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('cooking_food_blogger_linkedin_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('cooking_food_blogger_linkedin_url',array(
        'label' => esc_html__('Linkedin Link','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_top_slider',
        'setting' => 'cooking_food_blogger_linkedin_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('cooking_food_blogger_youtube_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    ));
    $wp_customize->add_control('cooking_food_blogger_youtube_url',array(
        'label' => esc_html__('YouTube Link','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_top_slider',
        'setting' => 'cooking_food_blogger_pintrest_url',
        'type'  => 'url'
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_slider_setting', array(
        'sanitize_callback' => 'Cooking_Food_Blogger_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Cooking_Food_Blogger_Customize_Pro_Version ( $wp_customize,'pro_version_slider_setting', array(
                'section'     => 'cooking_food_blogger_top_slider',
                'type'        => 'pro_options',
                'label'       => esc_html__( 'Customizer Options', 'cooking-food-blogger' ),
                'description' => esc_url( COOKING_FOOD_BLOGGER_URL ),
                'priority'    => 100
    )));

    // Our Services
    $wp_customize->add_section('cooking_food_blogger_services_section',array(
        'title' => esc_html__('Our Services','cooking-food-blogger'),
        'description' => esc_html__('Here you have to select category which will display perticular services in the home page.','cooking-food-blogger')
    ));

    $wp_customize->add_setting('cooking_food_blogger_services_setting', array(
        'default' => 0,
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'cooking_food_blogger_services_setting',array(
        'label'          => __( 'Enable Disable Service', 'cooking-food-blogger' ),
        'section'        => 'cooking_food_blogger_services_section',
        'settings'       => 'cooking_food_blogger_services_setting',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('cooking_food_blogger_services_short_heading',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_services_short_heading',array(
        'label' => esc_html__('Short Heading','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_services_section',
        'setting' => 'cooking_food_blogger_services_short_heading',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_services_long_heading',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_services_long_heading',array(
        'label' => esc_html__('Main Heading','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_services_section',
        'setting' => 'cooking_food_blogger_services_long_heading',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_services_button_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_services_button_text',array(
        'label' => esc_html__('Button Text','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_services_section',
        'setting' => 'cooking_food_blogger_services_button_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_services_button_url',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    ));
    $wp_customize->add_control('cooking_food_blogger_services_button_url',array(
        'label' => esc_html__('Button URL','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_services_section',
        'setting' => 'cooking_food_blogger_services_button_url',
        'type'  => 'text'
    ));

    $categories = get_categories();
    $cat_post = array();
    $cat_post[]= 'select';
    $i = 0;
    foreach($categories as $category){
        if($i==0){
            $default = $category->slug;
            $i++;
        }
        $cat_post[$category->slug] = $category->name;
    }

    $wp_customize->add_setting('cooking_food_blogger_services_sec_category',array(
        'default'   => 'select',
        'sanitize_callback' => 'cooking_food_blogger_sanitize_select',
    ));
    $wp_customize->add_control('cooking_food_blogger_services_sec_category',array(
        'type'    => 'select',
        'choices' => $cat_post,
        'label' => __('Select Category to display services','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_services_section',
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_service_setting', array(
        'sanitize_callback' => 'Cooking_Food_Blogger_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Cooking_Food_Blogger_Customize_Pro_Version ( $wp_customize,'pro_version_service_setting', array(
                'section'     => 'cooking_food_blogger_services_section',
                'type'        => 'pro_options',
                'label'       => esc_html__( 'Customizer Options', 'cooking-food-blogger' ),
                'description' => esc_url( COOKING_FOOD_BLOGGER_URL ),
                'priority'    => 100
    )));

    // Footer
    $wp_customize->add_section('cooking_food_blogger_site_footer_section', array(
        'title' => esc_html__('Footer', 'cooking-food-blogger'),
    ));

    $wp_customize->add_setting('cooking_food_blogger_show_hide_footer',array(
        'default' => true,
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox'
    ));
    $wp_customize->add_control('cooking_food_blogger_show_hide_footer',array(
        'type' => 'checkbox',
        'label' => __('Show / Hide Footer','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_site_footer_section',
        'priority' => 1,
    ));

    $wp_customize->add_setting('cooking_food_blogger_footer_bg_image',array(
        'default'   => '',
        'sanitize_callback' => 'esc_url_raw',
    ));
    $wp_customize->add_control( new WP_Customize_Image_Control($wp_customize,'cooking_food_blogger_footer_bg_image',array(
        'label' => __('Footer Background Image','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_site_footer_section',
        'priority' => 1,
    )));

    $wp_customize->add_setting('cooking_food_blogger_show_hide_copyright',array(
        'default' => true,
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox'
    ));
    $wp_customize->add_control('cooking_food_blogger_show_hide_copyright',array(
        'type' => 'checkbox',
        'label' => __('Show / Hide Copyright','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_site_footer_section',
    ));

    $wp_customize->add_setting('cooking_food_blogger_footer_text_setting', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control('cooking_food_blogger_footer_text_setting', array(
        'label' => __('Replace the footer text', 'cooking-food-blogger'),
        'section' => 'cooking_food_blogger_site_footer_section',
        'type' => 'text',
    ));

    $wp_customize->add_setting('cooking_food_blogger_copyright_background_color', array(
        'default'           => '',
        'sanitize_callback' => 'sanitize_hex_color',
    ));
    $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'cooking_food_blogger_copyright_background_color', array(
        'label'    => __('Copyright Background Color', 'cooking-food-blogger'),
        'section'  => 'cooking_food_blogger_site_footer_section',
    )));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_footer_setting', array(
        'sanitize_callback' => 'Cooking_Food_Blogger_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Cooking_Food_Blogger_Customize_Pro_Version ( $wp_customize,'pro_version_footer_setting', array(
            'section'     => 'cooking_food_blogger_site_footer_section',
            'type'        => 'pro_options',
            'label'       => esc_html__( 'Customizer Options', 'cooking-food-blogger' ),
            'description' => esc_url( COOKING_FOOD_BLOGGER_URL ),
            'priority'    => 100
    )));

    // Post Settings
     $wp_customize->add_section('cooking_food_blogger_post_settings',array(
        'title' => esc_html__('Post Settings','cooking-food-blogger'),
        'priority'   =>40,
    ));

    $wp_customize->add_setting('cooking_food_blogger_post_page_title',array(
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('cooking_food_blogger_post_page_title',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Title', 'cooking-food-blogger'),
        'section'     => 'cooking_food_blogger_post_settings',
        'description' => esc_html__('Check this box to enable title on post page.', 'cooking-food-blogger'),
    ));

    $wp_customize->add_setting('cooking_food_blogger_post_page_meta',array(
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('cooking_food_blogger_post_page_meta',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Meta', 'cooking-food-blogger'),
        'section'     => 'cooking_food_blogger_post_settings',
        'description' => esc_html__('Check this box to enable meta on post page.', 'cooking-food-blogger'),
    ));

    $wp_customize->add_setting('cooking_food_blogger_post_page_thumb',array(
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('cooking_food_blogger_post_page_thumb',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Thumbnail', 'cooking-food-blogger'),
        'section'     => 'cooking_food_blogger_post_settings',
        'description' => esc_html__('Check this box to enable thumbnail on post page.', 'cooking-food-blogger'),
    ));

    $wp_customize->add_setting('cooking_food_blogger_post_page_btn',array(
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('cooking_food_blogger_post_page_btn',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Post Page Button', 'cooking-food-blogger'),
        'section'     => 'cooking_food_blogger_post_settings',
        'description' => esc_html__('Check this box to enable btton on post page.', 'cooking-food-blogger'),
    ));

    $wp_customize->add_setting('cooking_food_blogger_single_post_thumb',array(
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('cooking_food_blogger_single_post_thumb',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Thumbnail', 'cooking-food-blogger'),
        'section'     => 'cooking_food_blogger_post_settings',
        'description' => esc_html__('Check this box to enable post thumbnail on single post.', 'cooking-food-blogger'),
    ));

    $wp_customize->add_setting('cooking_food_blogger_single_post_meta',array(
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('cooking_food_blogger_single_post_meta',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Meta', 'cooking-food-blogger'),
        'section'     => 'cooking_food_blogger_post_settings',
        'description' => esc_html__('Check this box to enable single post meta such as post date, author, category, comment etc.', 'cooking-food-blogger'),
    ));

    $wp_customize->add_setting('cooking_food_blogger_single_post_title',array(
            'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox',
            'default'           => 1,
    ));
    $wp_customize->add_control('cooking_food_blogger_single_post_title',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Title', 'cooking-food-blogger'),
        'section'     => 'cooking_food_blogger_post_settings',
        'description' => esc_html__('Check this box to enable title on single post.', 'cooking-food-blogger'),
    ));

    $wp_customize->add_setting('cooking_food_blogger_single_post_tags',array(
            'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox',
            'default'           => 1,
    ));
    $wp_customize->add_control('cooking_food_blogger_single_post_tags',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Post Tags', 'cooking-food-blogger'),
        'section'     => 'cooking_food_blogger_post_settings',
        'description' => esc_html__('Check this box to enable tags on single post.', 'cooking-food-blogger'),
    ));

    $wp_customize->add_setting('cooking_food_blogger_single_post_navigation_show_hide',array(
        'default' => true,
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox'
    ));
    $wp_customize->add_control('cooking_food_blogger_single_post_navigation_show_hide',array(
        'type' => 'checkbox',
        'label' => __('Show / Hide Post Navigation','cooking-food-blogger'),
        'section' => 'cooking_food_blogger_post_settings',
    ));

    $wp_customize->add_setting('cooking_food_blogger_single_post_comment_title',array(
        'default'=> 'Leave a Reply',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('cooking_food_blogger_single_post_comment_title',array(
        'label' => __('Add Comment Title','cooking-food-blogger'),
        'input_attrs' => array(
        'placeholder' => __( 'Leave a Reply', 'cooking-food-blogger' ),
        ),
        'section'=> 'cooking_food_blogger_post_settings',
        'type'=> 'text'
    ));

    $wp_customize->add_setting('cooking_food_blogger_single_post_comment_btn_text',array(
        'default'=> 'Post Comment',
        'sanitize_callback' => 'sanitize_text_field'
    ));

    $wp_customize->add_control('cooking_food_blogger_single_post_comment_btn_text',array(
        'label' => __('Add Comment Button Text','cooking-food-blogger'),
        'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'cooking-food-blogger' ),
        ),
        'section'=> 'cooking_food_blogger_post_settings',
        'type'=> 'text'
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_post_setting', array(
        'sanitize_callback' => 'Cooking_Food_Blogger_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Cooking_Food_Blogger_Customize_Pro_Version ( $wp_customize,'pro_version_post_setting', array(
                'section'     => 'cooking_food_blogger_post_settings',
                'type'        => 'pro_options',
                'label'       => esc_html__( 'Customizer Options', 'cooking-food-blogger' ),
                'description' => esc_url( COOKING_FOOD_BLOGGER_URL ),
                'priority'    => 100
    )));

    // Page Settings
    $wp_customize->add_section('cooking_food_blogger_page_settings',array(
        'title' => esc_html__('Page Settings','cooking-food-blogger'),
        'priority'   =>50,
    ));

    $wp_customize->add_setting('cooking_food_blogger_single_page_title',array(
            'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox',
            'default'           => 1,
    ));
    $wp_customize->add_control('cooking_food_blogger_single_page_title',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Page Title', 'cooking-food-blogger'),
        'section'     => 'cooking_food_blogger_page_settings',
        'description' => esc_html__('Check this box to enable title on single page.', 'cooking-food-blogger'),
    ));

    $wp_customize->add_setting('cooking_food_blogger_single_page_thumb',array(
        'sanitize_callback' => 'cooking_food_blogger_sanitize_checkbox',
        'default'           => 1,
    ));
    $wp_customize->add_control('cooking_food_blogger_single_page_thumb',array(
        'type'        => 'checkbox',
        'label'       => esc_html__('Enable Single Page Thumbnail', 'cooking-food-blogger'),
        'section'     => 'cooking_food_blogger_page_settings',
        'description' => esc_html__('Check this box to enable page thumbnail on single page.', 'cooking-food-blogger'),
    ));

    // Pro Version
    $wp_customize->add_setting( 'pro_version_single_page_setting', array(
        'sanitize_callback' => 'Cooking_Food_Blogger_sanitize_custom_control'
    ));
    $wp_customize->add_control( new Cooking_Food_Blogger_Customize_Pro_Version ( $wp_customize,'pro_version_single_page_setting', array(
                'section'     => 'cooking_food_blogger_page_settings',
                'type'        => 'pro_options',
                'label'       => esc_html__( 'Customizer Options', 'cooking-food-blogger' ),
                'description' => esc_url( COOKING_FOOD_BLOGGER_URL ),
                'priority'    => 100
    )));
    
}
add_action('customize_register', 'cooking_food_blogger_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function cooking_food_blogger_customize_partial_blogname(){
    bloginfo('name');
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function cooking_food_blogger_customize_partial_blogdescription(){
    bloginfo('description');
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function cooking_food_blogger_customize_preview_js(){
    wp_enqueue_script('cooking-food-blogger-customizer', esc_url(get_template_directory_uri()) . '/assets/js/customizer.js', array('customize-preview'), '20151215', true);
}
add_action('customize_preview_init', 'cooking_food_blogger_customize_preview_js');

/*
** Load dynamic logic for the customizer controls area.
*/
function cooking_food_blogger_panels_js() {
    wp_enqueue_style( 'cooking-food-blogger-customizer-layout-css', get_theme_file_uri( '/assets/css/customizer-layout.css' ) );
    wp_enqueue_script( 'cooking-food-blogger-customize-layout', get_theme_file_uri( '/assets/js/customize-layout.js' ), array(), '1.2', true );
}
add_action( 'customize_controls_enqueue_scripts', 'cooking_food_blogger_panels_js' );